@@ -1,5 +1,5 @@
 #include <R.h>
 
-void ar2cor(int *n, int *k,
+void ar2cov(int *n, int *k,
             double *a1, double *a2,
             double *r);
